# Mass
A python script to find the molecular mass in g/mol of a chemical equation
## Example
```
$ molmass C6H12O6
180.15588
$ molmass Cr2O7
215.98800
$ molmass C11H22
154.29238
```
## Setup
You can download using PyPi
Using pip:
```
$ pip install molmass
```
## License
Mass is licensed under the MIT License - see the LICENSE file for details.
